@@ -76,114 +76,67 @@ impl Kubectl {
             .map_err(from_kubeconfig_error)
     }
 
-    pub async fn ensure_global_k_is_installed<K>(&self, mut object: K) -> kube::Result<K>
+    pub async fn ensure_global_k_is_installed<K>(&self, object: K) -> kube::Result<K>
     where
         K: kube::ResourceExt + ser::Serialize + de::DeserializeOwned + Clone + fmt::Debug,
         <K as kube::Resource>::DynamicType: Default,
     {
-        let name = object.name();
-        let objects = self.api::<K>();
-        if let Ok(existing) = objects.get(&name).await {
-            object.meta_mut().resource_version = existing.resource_version();
-        }
-
-        let object = self.patch(object, objects).await?;
-
-        Ok(object)
+        self.ensure_global_k_is_installed_impl(object, false).await
     }
 
     pub async fn ensure_namespaced_k_is_installed<K>(
         &self,
-        mut object: K,
+        object: K,
         namespace: &str,
     ) -> kube::Result<K>
     where
         K: kube::Resource + ser::Serialize + de::DeserializeOwned + Clone + fmt::Debug,
         <K as kube::Resource>::DynamicType: Default,
     {
-        let name = object.name();
-        let objects = self.namespaced_api::<K>(namespace);
-        if let Ok(existing) = objects.get(&name).await {
-            object.meta_mut().resource_version = existing.resource_version();
-        }
-
-        let object = self.patch(object, objects).await?;
-
-        Ok(object)
+        self.ensure_namespaced_k_is_installed_impl(object, namespace, false)
+            .await
     }
 
-    pub async fn ensure_default_namespaced_k_is_installed<K>(
-        &self,
-        mut object: K,
-    ) -> kube::Result<K>
+    pub async fn ensure_default_namespaced_k_is_installed<K>(&self, object: K) -> kube::Result<K>
     where
         K: kube::Resource + ser::Serialize + de::DeserializeOwned + Clone + fmt::Debug,
         <K as kube::Resource>::DynamicType: Default,
     {
-        let name = object.name();
-        let objects = self.default_namespaced_api::<K>();
-        if let Ok(existing) = objects.get(&name).await {
-            object.meta_mut().resource_version = existing.resource_version();
-        }
-
-        let object = self.patch(object, objects).await?;
-
-        Ok(object)
+        self.ensure_default_namespaced_k_is_installed_impl(object, false)
+            .await
     }
 
-    pub async fn ensure_global_k_is_installed_forced<K>(&self, mut object: K) -> kube::Result<K>
+    pub async fn ensure_global_k_is_installed_forced<K>(&self, object: K) -> kube::Result<K>
     where
         K: kube::ResourceExt + ser::Serialize + de::DeserializeOwned + Clone + fmt::Debug,
         <K as kube::Resource>::DynamicType: Default,
     {
-        let name = object.name();
-        let objects = self.api::<K>();
-        if let Ok(existing) = objects.get(&name).await {
-            object.meta_mut().resource_version = existing.resource_version();
-        }
-
-        let object = self.force_patch(object, objects).await?;
-
-        Ok(object)
+        self.ensure_global_k_is_installed_impl(object, true).await
     }
 
     pub async fn ensure_namespaced_k_is_installed_forced<K>(
         &self,
-        mut object: K,
+        object: K,
         namespace: &str,
     ) -> kube::Result<K>
     where
         K: kube::Resource + ser::Serialize + de::DeserializeOwned + Clone + fmt::Debug,
         <K as kube::Resource>::DynamicType: Default,
     {
-        let name = object.name();
-        let objects = self.namespaced_api::<K>(namespace);
-        if let Ok(existing) = objects.get(&name).await {
-            object.meta_mut().resource_version = existing.resource_version();
-        }
-
-        let object = self.force_patch(object, objects).await?;
-
-        Ok(object)
+        self.ensure_namespaced_k_is_installed_impl(object, namespace, true)
+            .await
     }
 
     pub async fn ensure_default_namespaced_k_is_installed_forced<K>(
         &self,
-        mut object: K,
+        object: K,
     ) -> kube::Result<K>
     where
         K: kube::Resource + ser::Serialize + de::DeserializeOwned + Clone + fmt::Debug,
         <K as kube::Resource>::DynamicType: Default,
     {
-        let name = object.name();
-        let objects = self.default_namespaced_api::<K>();
-        if let Ok(existing) = objects.get(&name).await {
-            object.meta_mut().resource_version = existing.resource_version();
-        }
-
-        let object = self.force_patch(object, objects).await?;
-
-        Ok(object)
+        self.ensure_default_namespaced_k_is_installed_impl(object, true)
+            .await
     }
 
     pub async fn get_k_logs<K>(&self, object: &K) -> kube::Result<String>
